"use strict";
var _plugin = /*#__PURE__*/ _interopRequireDefault(require("tailwindcss/plugin"));
var _dataTypes = require("tailwindcss/lib/util/dataTypes");
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
module.exports = (0, _plugin.default)(function containerQueries(param) {
    var matchUtilities = param.matchUtilities, matchVariant = param.matchVariant, theme = param.theme;
    var parseValue = function parseValue(value) {
        var ref, ref1, ref2, ref3, ref4;
        // _ -> space
        value = (0, _dataTypes.normalize)(value);
        var ref5;
        // If just a number then it's a min-width
        var numericValue = (ref5 = (ref = value.match(/^(\d+\.\d+|\d+|\.\d+)\D+/)) === null || ref === void 0 ? void 0 : ref[1]) !== null && ref5 !== void 0 ? ref5 : null;
        if (numericValue !== null) {
            value = "(min-width: ".concat(value, ")");
        }
        // Support for shorthand syntax(es)
        // Pending change on extractor ignoring @[min-w:stuff]
        // value = value.replace(/^min-w:(.*)$/, '(min-width:\1)')
        // value = value.replace(/^max-h:(.*)$/, '(max-width:\1)')
        // value = value.replace(/^min-y:(.*)$/, '(min-height:\1)')
        // value = value.replace(/^max-h:(.*)$/, '(max-height:\1)')
        // If it doesn't start / end with parens then it's not valid (for now)
        if (!value.startsWith("(") || !value.endsWith(")")) {
            return null;
        }
        var ref6;
        // Parse the value into {minX, minY, maxX, maxY, raw} values
        // This will make suring simpler
        var minX = (ref6 = (ref1 = value.match(/min-width:\s*(\d+\.\d+|\d+|\.\d+)\D+/)) === null || ref1 === void 0 ? void 0 : ref1[1]) !== null && ref6 !== void 0 ? ref6 : null;
        var ref7;
        var maxX = (ref7 = (ref2 = value.match(/max-width:\s*(\d+\.\d+|\d+|\.\d+)\D+/)) === null || ref2 === void 0 ? void 0 : ref2[1]) !== null && ref7 !== void 0 ? ref7 : null;
        var ref8;
        var minY = (ref8 = (ref3 = value.match(/min-height:\s*(\d+\.\d+|\d+|\.\d+)\D+/)) === null || ref3 === void 0 ? void 0 : ref3[1]) !== null && ref8 !== void 0 ? ref8 : null;
        var ref9;
        var maxY = (ref9 = (ref4 = value.match(/max-height:\s*(\d+\.\d+|\d+|\.\d+)\D+/)) === null || ref4 === void 0 ? void 0 : ref4[1]) !== null && ref9 !== void 0 ? ref9 : null;
        var minXf = minX === null ? Number.MIN_SAFE_INTEGER : parseFloat(minX);
        var maxXf = maxX === null ? Number.MAX_SAFE_INTEGER : parseFloat(maxX);
        var minYf = minY === null ? Number.MIN_SAFE_INTEGER : parseFloat(minY);
        var maxYf = maxY === null ? Number.MAX_SAFE_INTEGER : parseFloat(maxY);
        return {
            raw: value,
            sortable: minX !== null || maxX !== null || minY !== null || maxY !== null,
            minX: minXf,
            maxX: maxXf,
            minY: minYf,
            maxY: maxYf
        };
    };
    var ref;
    var values = (ref = theme("containers")) !== null && ref !== void 0 ? ref : {};
    matchUtilities({
        container: function(value, param) {
            var modifier = param.modifier;
            return {
                "container-type": value,
                "container-name": modifier
            };
        }
    }, {
        values: {
            DEFAULT: "inline",
            block: "block",
            inline: "inline"
        },
        modifiers: "any"
    });
    matchVariant("@", function() {
        var value = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : "", modifier = (arguments.length > 1 ? arguments[1] : void 0).modifier;
        var parsed = parseValue(value);
        return parsed !== null ? "@container ".concat(modifier !== null && modifier !== void 0 ? modifier : "", " ").concat(parsed.raw) : [];
    }, {
        values: values,
        sort: function sort(aVariant, bVariant) {
            var a = parseValue(aVariant.value);
            var b = parseValue(bVariant.value);
            if (a === null || b === null) return 0;
            var _modifier;
            var aLabel = (_modifier = aVariant.modifier) !== null && _modifier !== void 0 ? _modifier : "";
            var _modifier1;
            var bLabel = (_modifier1 = bVariant.modifier) !== null && _modifier1 !== void 0 ? _modifier1 : "";
            // Put "raw" values at the end
            if (a.sortable === false && b.sortable === false) {
                return 0;
            } else if (a.sortable === false) {
                return 1;
            } else if (b.sortable === false) {
                return -1;
            }
            // Order by min width / height and max width / height
            var order = a.minX - b.minX || a.minY - b.minY || b.maxX - a.maxX || b.maxY - a.maxY;
            if (order !== 0) {
                return order;
            }
            // Explicitly move empty labels to the end
            if (aLabel === "" && bLabel !== "") {
                return 1;
            } else if (aLabel !== "" && bLabel === "") {
                return -1;
            }
            // Sort labels alphabetically in the English locale
            // We are intentionally overriding the locale because we do not want the sort to
            // be affected by the machine's locale (be it a developer or CI environment)
            return aLabel.localeCompare(bLabel, "en", {
                numeric: true
            });
        }
    });
});
